==> haskell-prim-uniq-0.2-126-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-prim-uniq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 prim-uniq
version:              0.2
visibility:           public
id:                   prim-uniq-0.2-1pVuFHOgAPl8nLjwu4RYCr
key:                  prim-uniq-0.2-1pVuFHOgAPl8nLjwu4RYCr
license:              LicenseRef-PublicDomain
maintainer:           Obsidian Systems, LLC <maintainer@obsidian.systems>
author:               James Cook <mokus@deepbondi.net>
stability:            provisional
homepage:             https://github.com/obsidiansystems/prim-uniq
synopsis:             Opaque unique identifiers in primitive state monads
description:
    Opaque unique identifiers in primitive state monads
    and a GADT-like type using them as witnesses of type
    equality.

category:             Data, Dependent Types
abi:                  abec327eba090601d124993ca58c8c3b
exposed:              True
exposed-modules:
    Data.Unique.Prim Data.Unique.Tag Unsafe.Unique.Prim
    Unsafe.Unique.Tag

import-dirs:          /usr/lib/ghc-9.2.8/site-local/prim-uniq-0.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/prim-uniq-0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-prim-uniq
hs-libraries:         HSprim-uniq-0.2-1pVuFHOgAPl8nLjwu4RYCr
depends:
    base-4.16.4.0 dependent-sum-0.7.2.0-HZTdxGf9GLyIdxrqjlDFcm
    primitive-0.7.4.0-2yvrjkKbYif9hwxczpmLrN

haddock-interfaces:   /usr/share/doc/haskell-prim-uniq/html/prim-uniq.haddock
haddock-html:         /usr/share/doc/haskell-prim-uniq/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-prim-uniq-0.2-127-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-prim-uniq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 prim-uniq
version:              0.2
visibility:           public
id:                   prim-uniq-0.2-DYL9DJYZpZqJYEiF5RwlZY
key:                  prim-uniq-0.2-DYL9DJYZpZqJYEiF5RwlZY
license:              LicenseRef-PublicDomain
maintainer:           Obsidian Systems, LLC <maintainer@obsidian.systems>
author:               James Cook <mokus@deepbondi.net>
stability:            provisional
homepage:             https://github.com/obsidiansystems/prim-uniq
synopsis:             Opaque unique identifiers in primitive state monads
description:
    Opaque unique identifiers in primitive state monads
    and a GADT-like type using them as witnesses of type
    equality.

category:             Data, Dependent Types
abi:                  8f1a897feee27ee39a47ee1cfe29765c
exposed:              True
exposed-modules:
    Data.Unique.Prim Data.Unique.Tag Unsafe.Unique.Prim
    Unsafe.Unique.Tag

import-dirs:          /usr/lib/ghc-9.2.8/site-local/prim-uniq-0.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/prim-uniq-0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-prim-uniq
hs-libraries:         HSprim-uniq-0.2-DYL9DJYZpZqJYEiF5RwlZY
depends:
    base-4.16.4.0 dependent-sum-0.7.2.0-9WHFMCivjW71nK3atirmTO
    primitive-0.7.4.0-2yvrjkKbYif9hwxczpmLrN

haddock-interfaces:   /usr/share/doc/haskell-prim-uniq/html/prim-uniq.haddock
haddock-html:         /usr/share/doc/haskell-prim-uniq/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
